@@ -39,16 +39,17 @@
 
 class QSqlRelationalTableModel;
 
-// Last db update 0.0.7
-// Previous db update 0.0.6
-const float DBVersionf = 0.007;
+// Last db update 0.0.6
+// Previous db update 0.0.7
+const float DBVersionf = 0.009;
 
 class DataBase
 {
 
 public:
     DataBase();
-    DataBase(const QString _softVersion, bool  inmemoryonly = false);
+    //DataBase(const QString _softVersion, bool  inmemoryonly = false);
+    DataBase(const QString _softVersion);
     ~DataBase();
     bool createConnection();
 
@@ -81,48 +82,62 @@ public:
     bool updateIfNeeded();
     void compress();
 
-
+    bool updateTheEntityTableISONames();
+    bool updateTableLogs();
 
 private:
     bool createDataBase();
     bool isTheDBCreated();
+    bool hasTheTableData(const QString _tableName);
     bool updateToLatest();
     bool updateTo003(); // Updates the DB to 0.0.3
     bool updateTo004();
     bool updateTo005();
     bool updateTo006();
     bool updateTo007();
+    bool updateTo008();
+    bool updateTo009(); // Updates DB and add the Satellite tables
     bool updateTableLog(const int _v);
 
-
     bool createTheBandQuickReference();
     bool createTheModeQuickReference();
 
-    bool updateLog(); // Updates the log table
-    bool createTableLog(bool temp = false); // false creates the prouction DB. True a temporal one.
-    bool createTableLogs();
+    //bool updateLog(); // Updates the log table
+    bool createTableLog(bool temp = false); // false creates the production DB. True a temporal one.
+    bool createTableLogs(const bool real=true); // real = true creates the production DB. False a temporal one.
+
+    bool createTableEntity(const bool NoTmp);
+    bool updateTableEntity();
+
     bool createTablePropModes();
     bool createTableClubLogStatus();
     bool populateTableClubLogStatus();
+
     bool createTableMode(const bool NoTmp);
     bool populateTableMode(const bool NoTmp);
+    bool updateTheModeTableAndSyncLog();
+
     bool createTableBand(const bool NoTmp);
     bool populateTableBand(const bool NoTmp);
 
+    bool createTableSatellites(const bool NoTmp);
+    bool populateTableSatellites(const bool NoTmp);
+
     bool recreateContestData();
     bool createTableContest();
     bool populateContestData();
     bool populatePropagationModes();
 
     bool howManyQSOsInLog(const int i);
-    //void showError(const QString _errorC);
+    void showError();
 
-    bool moveFromModeIdToSubmodeId();
+    //bool moveFromModeIdToSubmodeId();
     bool updateModeIdFromSubModeId();
     bool updateBandIdTableLogToNewOnes();
     bool updateBandIdTableAward(const int _db);
     bool updateModeIdTableAward(const int _db);
 
+    bool created;
     float dbVersion;    // The current version of the DB. May differ from latestReaded if we are updating the DB!
     QString softVersion;
     float latestReaded; // The latest version of DB readed in the DB itself
