@@ -31,11 +31,18 @@ public:
 
     virtual QString getFreqFromBandId(const int _id);
     virtual int getBandIdFromFreq(const double _n);
+    virtual double getLowLimitBandFromBandName(const QString _sm);
+    virtual double getLowLimitBandFromBandId(const QString _sm);
+
     virtual QStringList getBands();
     virtual QStringList getModes();
+    virtual QStringList sortBandNamesBottonUp(const QStringList _qs);
+    virtual QStringList getBandIDs();
+    virtual QStringList getModesIDs();
     virtual QStringList getBandsInLog(const int _log);
     virtual QStringList getModesInLog(const int _log);
 
+
     virtual int getLastQSOid();
     virtual bool clearLog();
 
@@ -61,6 +68,7 @@ public:
     virtual bool isWARC(const int _band);
     virtual bool isVHF(const int _band);
 
+
     virtual QString getCallFromId(const int _qsoId);
     virtual QStringList getClubLogRealTimeFromId(const int _qsoId);
     // Complete with previous
@@ -74,6 +82,9 @@ public:
     virtual int getContinentIdFromContinentShortName(const QString _n);
     virtual QString getContinentShortNameFromEntity(const int _n);
     virtual int getContinentIdFromEntity(const int _n);
+    virtual QStringList getContinentShortNames();
+    virtual bool isValidContinentShortName(const QString _n);
+
     virtual int getCQzFromPrefix(const QString _p);
     virtual int getCQzFromEntity(const int _n);
     virtual int getITUzFromEntity(const int _n);
@@ -88,6 +99,7 @@ public:
     virtual int getDXCCFromPrefix(const QString _p);
     virtual QString getEntityPrefixes(const int _enti);
     virtual QStringList getEntitiesNames();
+    virtual int getHowManyEntities();
 
     virtual QStringList getOperatingYears(const int _currentLog);
     virtual void compressDB();
@@ -104,6 +116,7 @@ public:
 
     virtual QStringList getBandNames();
     virtual QStringList getPropModeList();
+    virtual QStringList getSatellitesList();
 
     virtual QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
 
@@ -115,7 +128,8 @@ public:
     virtual bool addNewLog (const QStringList _qs);
     virtual bool doesThisLogExist(const int _log);
 
-
+    virtual bool updateISONames(); // Update the entities ISO names for the flags
+    virtual QString getISOName(const int _n);
 
 
 /*
@@ -127,7 +141,7 @@ public:
     virtual int getPoints();
 */
 private:
-
+    virtual QStringList sortBandIdBottonUp(const QStringList _qs);
    // int points;
    // int multipliers;
 
