@@ -29,12 +29,12 @@
 
 DataProxy_SQLite::DataProxy_SQLite()
 {
-   //qDebug() << "DataProxy_SQLite::DataProxy_SQLite" << endl;
+  //qDebug() << "DataProxy_SQLite::DataProxy_SQLite" << endl;
     db = new DataBase(0);
    //qDebug() << "DataProxy_SQLite::DataProxy_SQLite 1" << endl;
-    //dbCreated = db->createConnection();
-    //dbCreated = db->createBandModeMaps();
-   //qDebug() << "DataProxy_SQLite::DataProxy_SQLite - END" << endl;
+    dbCreated = db->createConnection();
+    dbCreated = db->createBandModeMaps();
+  //qDebug() << "DataProxy_SQLite::DataProxy_SQLite - END" << endl;
 
 
 }
@@ -156,7 +156,7 @@ bool DataProxy_SQLite::isModeDeprecated (const QString _sm)
 
 int DataProxy_SQLite::getIdFromBandName(const QString& _bandName)
 {
-    //qDebug() << "DataProxy_SQLite::getIdFromBandName: " << _bandName  << "/" << QString::number(db->getBandIDFromName2(_bandName))<< endl;
+   //qDebug() << "DataProxy_SQLite::getIdFromBandName: " << _bandName  << "/" << QString::number(db->getBandIDFromName2(_bandName))<< endl;
     if (_bandName.length()<1)
     {
         return -3;
@@ -284,18 +284,118 @@ int DataProxy_SQLite::getBandIdFromFreq(const double _n)
     return -1;
 }
 
+
+double DataProxy_SQLite::getLowLimitBandFromBandName(const QString _sm)
+{
+    //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandName" << endl;
+    QSqlQuery query;
+    QString stringQuery = QString("SELECT lower FROM band WHERE name='%1'").arg(_sm.toUpper());
+    query.exec(stringQuery);
+    query.next();
+    if (query.isValid())
+    {
+        if ( (query.value(1)).toDouble()<0 )
+        {
+            //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandName: -1.0-1" << endl;
+            return -1.0;
+        }
+        else
+        {
+            //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandName: " << QString::number((query.value(0)).toDouble()) << endl;
+            return (query.value(0)).toDouble();
+        }
+    }
+    else
+    {
+        //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandName: -1.0-2" << endl;
+        return -1.0;
+    }
+
+    //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandName: -1.0-3" << endl;
+    return -1.0;
+}
+
+
+double DataProxy_SQLite::getLowLimitBandFromBandId(const QString _sm)
+{
+    //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandId" << endl;
+    QSqlQuery query;
+    QString stringQuery = QString("SELECT lower FROM band WHERE id='%1'").arg(_sm.toUpper());
+    query.exec(stringQuery);
+    query.next();
+    if (query.isValid())
+    {
+        if ( (query.value(1)).toDouble()<0 )
+        {
+            //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandId: -1.0-1" << endl;
+            return -1.0;
+        }
+        else
+        {
+            //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandId: " << QString::number((query.value(0)).toDouble()) << endl;
+            return (query.value(0)).toDouble();
+        }
+    }
+    else
+    {
+        //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandId: -1.0-2" << endl;
+        return -1.0;
+    }
+
+    //qDebug() << "DataProxy_SQLite::getLowLimitBandFromBandId: -1.0-3" << endl;
+    return -1.0;
+}
+
 QStringList DataProxy_SQLite::getBands()
 {
-    QStringList bands = QStringList();
+  //qDebug() << "DataProxy_SQLite::getBands - DEPRECATED please use getBandNames - TODO: Remove this function and change the calls" << endl;
+    return getBandNames();
+
+
+/*
+   QStringList bands = QStringList();
     QSqlQuery query("SELECT name FROM band");
     while (query.next()) {
         if (query.isValid()){
             bands << query.value(0).toString();
         }
-
     }
+    //return bands;
+    return sortBandNamesBottonUp(bands);
+*/
+}
 
-    return bands;
+QStringList DataProxy_SQLite::getBandNames()
+{
+   //qDebug() << "DataProxy_SQLite::getBandNames" << endl;
+    QStringList bands = QStringList();
+    QSqlQuery query;
+    QString stringQuery;
+    bool sqlOK;
+    stringQuery = QString("SELECT DISTINCT name from band");
+    sqlOK = query.exec(stringQuery);
+    if (sqlOK)
+    {
+        while(query.next())
+        {
+            if (query.isValid())
+            {
+                stringQuery = (query.value(0)).toString();
+                bands.append(stringQuery);
+            }
+            else
+            {
+                return QStringList();
+            }
+
+        }
+        return sortBandNamesBottonUp(bands);
+        //return bands;
+    }
+    else
+    {
+         return QStringList();
+    }
 }
 
 QStringList DataProxy_SQLite::getModes()
@@ -310,8 +410,93 @@ QStringList DataProxy_SQLite::getModes()
     return modes;
 }
 
+QStringList DataProxy_SQLite::sortBandNamesBottonUp(const QStringList _qs)
+{
+    //Receives a list of band names, sorts it from the lower band to the upper band and returns
+  //qDebug() << "DataProxy_SQLite::sortBandNamesBottonUp" << endl;
+
+   //Next lines to be commented out
+   for (int i=0; i<_qs.length();i++)
+   {
+       //qDebug() << "DataProxy_SQLite::sortBandNamesBottonUp - band: " << _qs.at(i) << endl;
+   }
+   //Previous lines to be commented out
+
+    QMap<double, QString> map;
+    QStringList qs;
+    qs.clear();
+
+
+    for (int j=0; j<_qs.count(); j++)
+    {
+        map.insert(getLowLimitBandFromBandName(_qs.at(j)), _qs.at(j));
+    }
+
+    QMap<double, QString>::const_iterator i = map.constBegin();
+
+    while (i != map.constEnd()) {
+        qs << i.value();
+        ++i;
+    }
+
+   //qDebug() << "DataProxy_SQLite::sortBandNamesBottonUp - END -lengh = " << QString::number(qs.length()) << endl;
+    //qs.removeDuplicates();
+    return qs;
+}
+
+
+QStringList DataProxy_SQLite::getBandIDs()
+{
+    //qDebug() << "DataProxy_SQLite::getBandIDs" << endl;
+    QStringList bands = QStringList();
+    QSqlQuery query("SELECT id FROM band");
+    while (query.next()) {
+        if (query.isValid()){
+            bands << query.value(0).toString();
+        }
+    }
+    return sortBandIdBottonUp(bands);
+}
+
+QStringList DataProxy_SQLite::sortBandIdBottonUp(const QStringList _qs)
+{
+    //Receives a list of band id, sorts it from the lower band to the upper band and returns
+    QMap<double, QString> map;
+    QStringList qs;
+    qs.clear();
+
+
+    for (int j=0; j<_qs.count(); j++)
+    {
+        map.insert(getLowLimitBandFromBandId(_qs.at(j)), _qs.at(j));
+    }
+
+    QMap<double, QString>::const_iterator i = map.constBegin();
+
+    while (i != map.constEnd()) {
+        qs << i.value();
+        ++i;
+    }
+
+    return qs;
+}
+
+QStringList DataProxy_SQLite::getModesIDs()
+{
+    QStringList modes = QStringList();
+    QSqlQuery query("SELECT id FROM mode");
+    while (query.next()) {
+        if (query.isValid()){
+            modes << query.value(0).toString();
+        }
+    }
+    return modes;
+}
+
+
 QStringList DataProxy_SQLite::getBandsInLog(const int _log)
 {
+    //qDebug() << "DataProxy_SQLite::getBandsInLog: " << endl;
     QStringList bands = QStringList();
     QString stringQuery = QString();
     if (_log <= 0)
@@ -329,7 +514,8 @@ QStringList DataProxy_SQLite::getBandsInLog(const int _log)
             bands << query.value(0).toString();
         }
     }
-    return bands;
+    return sortBandNamesBottonUp(bands);
+    //return bands;
 }
 
 QStringList DataProxy_SQLite::getModesInLog(const int _log)
@@ -1626,40 +1812,6 @@ QStringList DataProxy_SQLite::getContestOverlays()
     return QStringList();
 }
 
-QStringList DataProxy_SQLite::getBandNames()
-{
-
-    QStringList bands = QStringList();
-    QSqlQuery query;
-    QString stringQuery;
-    bool sqlOK;
-    stringQuery = QString("SELECT DISTINCT name from band");
-    sqlOK = query.exec(stringQuery);
-    if (sqlOK)
-    {
-        while(query.next())
-        {
-            if (query.isValid())
-            {
-                stringQuery = (query.value(0)).toString();
-                bands.append(stringQuery);
-            }
-            else
-            {
-                return QStringList();
-            }
-
-        }
-
-        return bands;
-    }
-    else
-    {
-         return QStringList();
-    }
-}
-
-
 QStringList DataProxy_SQLite::getPropModeList()
 {
    //qDebug()  << "DataProxy_SQLite::getPropModeLists"  << endl;
@@ -1691,6 +1843,36 @@ QStringList DataProxy_SQLite::getPropModeList()
     return qs;
 }
 
+QStringList DataProxy_SQLite::getSatellitesList()
+{
+    //qDebug()  << "DataProxy_SQLite::getSatellitesList"  << endl;
+     QString aux = QString();
+     QStringList qs;
+     qs.clear();
+     QString stringQuery = QString("SELECT satarrlid, satname FROM satellites");
+     QSqlQuery query;
+
+     if (query.exec(stringQuery))
+     {
+         while ( (query.next())) {
+             if (query.isValid())
+             {
+                 aux.clear();
+                 aux = (query.value(0)).toString() + " - " + (query.value(1)).toString();
+                 qs << aux;
+             }
+             else
+             {
+             }
+         }
+
+     }
+     else
+     {
+         return QStringList();
+     }
+     return qs;
+}
 
 QStringList DataProxy_SQLite::getValidCatOptions(const int _currentCat, const int _lowerCat)
 {
@@ -2015,45 +2197,79 @@ int DataProxy_SQLite::getHowManyQSOInLog(const int _log)
 
 bool DataProxy_SQLite::addNewLog (const QStringList _qs)
 {
-    //qDebug() << "SetupPageLogs::addNewLog: " << _qs.at(2) << endl;
+   //qDebug() << "SetupPageLogs::addNewLog: " << _qs.at(2) << "/" << _qs.at(5) << "/" << _qs.at(6) << endl;
 
     //_qs << dateString << stationCallsign << _qs.at(4) << comment << _qs.at(12);
     //qDebug() << "SetupPageLogs::slotAnalyzeNewLogData:  " << _qs.at(4) << "/" << _qs.at(12) << endl;
-    // Date/Call/"DX"/comment/"1"
+    // Date/Call/Operators/"DX"/comment/"1"
 
-    if (_qs.size()!=5)
+    if (_qs.size()!=8)
     {
+       //qDebug() << "SetupPageLogs::addNewLog: != 8"  << endl;
         return false;
     }
+   //qDebug() << "SetupPageLogs::addNewLog: Has the appropriate length"  << endl;
 
     QString aux = QString();
     int nameCol = -1;
 
     QString _dateString = _qs.at(0);
-    QString _stationCallsign = _qs.at(1);
-    QString _typeContest = _qs.at(2);
-    QString _comment = _qs.at(3);
-    QString _typeContestN = _qs.at(4);
+    QString _stationCallsign = _qs.at(1);    
+    QString _operators = _qs.at(2);
 
+    //_operators.clear();
+    //_operators << (_qs.at(2)).split(',', QString::SkipEmptyParts);
+    QString _typeContest = _qs.at(3);
+    QString _comment = _qs.at(4);
+    QString _typeContestN = _qs.at(5);
+    QString id = _qs.at(6);
+    QString editing = _qs.at(7);
 
-    QString queryString = QString("SELECT * FROM logs WHERE logdate='%1' AND stationcall='%2' AND logtype='%3' AND logtypen='%4'").arg(_dateString).arg(_stationCallsign).arg(_typeContest).arg(_typeContestN);
+    QString queryString;
+    QSqlQuery query;
+    bool sqlOK;
+
+    if (editing == "1")
+    { // We are editing
+       //qDebug() << "SetupPageLogs::addNewLog: We are editing!" << endl;
+        queryString = QString("UPDATE logs SET logdate = '%1', stationcall = '%2', operators = '%3', comment = '%4',  logtype = '%5', logtypen = '%6' WHERE id = '%7'").arg(_dateString).arg(_stationCallsign).arg(_operators).arg(_comment).arg(_typeContest).arg(_typeContestN).arg(id);
+        sqlOK = query.exec(queryString);
+        if (sqlOK)
+        {
+           //qDebug() << "SetupPageLogs::addNewLog: Editing OK!" << endl;
+            return true;
+        }
+        else
+        {
+           //qDebug() << "SetupPageLogs::addNewLog: Editing NOK!" << endl;
+            return false;
+        }
+        return false;
+    }
+
+   //qDebug() << "SetupPageLogs::addNewLog: We are adding a new log" << endl;
+
+    // First we check if the log is already there
+    queryString = QString("SELECT id FROM logs WHERE logdate='%1' AND stationcall='%2' AND logtype='%3' AND logtypen='%4'").arg(_dateString).arg(_stationCallsign).arg(_typeContest).arg(_typeContestN);
     //"logs"
     //"id, logdate, stationcall, comment, logtype"
     //qDebug() << "SetupPageLogs::addNewLog query1: " << queryString << endl;
-    QSqlQuery query;
 
-    bool sqlOK = query.exec(queryString);
+    sqlOK = query.exec(queryString);
+
     QSqlRecord rec = query.record(); // Number of columns
 
-    while ( (query.next()) && (query.isValid()) )
+    if ( (query.next()) && (query.isValid()) )
     {
-        nameCol = rec.indexOf("id");
-        aux = (query.value(nameCol)).toString();
+        //nameCol = rec.indexOf("id");
+        //aux = (query.value(nameCol)).toString();
         //qDebug() << "SetupPageLogs::addNewLog: id = " << aux << endl;
         return false;
     }
-    queryString = QString("INSERT INTO logs (logdate, stationcall, comment, logtype, logtypen) values('%1','%2','%3','%4', '%5')").arg(_dateString).arg(_stationCallsign).arg(_comment).arg(_typeContest).arg(_typeContestN);
 
+    //Now we add the new log
+
+    queryString = QString("INSERT INTO logs (logdate, stationcall, operators, comment, logtype, logtypen) values('%1','%2','%3','%4', '%5', '%6')").arg(_dateString).arg(_stationCallsign).arg(_operators).arg(_comment).arg(_typeContest).arg(_typeContestN);
     //qDebug() << "SetupPageLogs::addNewLog query1: " << queryString << endl;
     sqlOK = query.exec(queryString);
     if (sqlOK)
@@ -2067,6 +2283,8 @@ bool DataProxy_SQLite::addNewLog (const QStringList _qs)
     return false;
 }
 
+
+
 bool DataProxy_SQLite::doesThisLogExist(const int _log)
 {
     QSqlQuery query;
@@ -2171,6 +2389,62 @@ int DataProxy_SQLite::getContinentIdFromEntity(const int _n)
     }
 }
 
+QStringList DataProxy_SQLite::getContinentShortNames()
+{
+
+    QSqlQuery query;
+    QString aux;
+    QStringList continents;
+    continents.clear();
+    aux = QString("SELECT shortname FROM continent");
+    if (query.exec(aux))
+    {
+        while (query.next())
+        {
+            if (query.isValid())
+            {
+                continents << query.value(0).toString();
+            }
+        }
+        return continents;
+    }
+    else
+    {
+        return QStringList();
+    }
+    return QStringList();
+}
+
+bool DataProxy_SQLite::isValidContinentShortName(const QString _n)
+{
+    QString stringQuery = QString("SELECT id FROM continent WHERE shortname ='%1'").arg(_n);
+    QSqlQuery query;
+    if (query.exec(stringQuery))
+    {
+        if (query.next())
+        {
+            if (query.isValid())
+            {
+                return true;
+            }
+            else
+            {
+                return false;
+            }
+        }
+        else
+        {
+            return false;
+        }
+
+    }
+    else
+    {
+        return false;
+    }
+    return false;
+}
+
 int DataProxy_SQLite::getITUzFromPrefix(const QString _p)
 {
     QSqlQuery query;
@@ -2536,3 +2810,82 @@ QStringList DataProxy_SQLite::getEntitiesNames()
     }
     return qs;
 }
+
+int DataProxy_SQLite::getHowManyEntities()
+{
+    QSqlQuery query;
+    QString aux;
+    aux = QString("SELECT count(id) FROM entity");
+    if (query.exec(aux))
+    {
+        query.next();
+        if (query.isValid())
+        {
+            return (query.value(0)).toInt();
+        }
+        else
+        {
+            return 0;
+        }
+
+    }
+    else
+    {
+        return 0;
+    }
+}
+
+bool DataProxy_SQLite::updateISONames()
+{
+   //qDebug()  << "DataProxy_SQLite::updateISONames"  << endl;
+    bool result;
+    result = db->updateTheEntityTableISONames();
+
+
+
+    return result;
+}
+
+QString DataProxy_SQLite::getISOName(const int _n)
+{
+    //qDebug()  << "DataProxy_SQLite::getISONames: " << QString::number(_n)  << endl;
+    if (_n <= 0 )
+    {
+        return "un"; // When no flag is known, we return the UN flag
+    }
+
+    QString queryString, aux;
+    QSqlQuery query;
+    aux.clear();
+    queryString = QString("SELECT isoname FROM entity WHERE dxcc='%1'").arg(_n);
+    if (!query.exec(queryString))
+    {
+       //qDebug()  << "DataProxy_SQLite::getISOName: Query error"  << endl;
+        return "nu"; // When no flag is known, we return the UN flag
+    }
+    else
+    {
+        query.next();
+
+        if (query.isValid()){
+            //qDebug()  << "DataProxy_SQLite::getISOName: ISO Name: " << (query.value(0)).toString() << endl;
+            aux = (query.value(0)).toString();
+            if (aux.length()>1)
+            {
+                return aux;
+            }
+            else
+            {
+                return "un"; // When no flag is known, we return the UN flag
+            }
+
+        }
+        else
+        {
+             //qDebug()  << "DataProxy_SQLite::getISOName: NO ISO Name: "  << endl;
+            return "un"; // When no flag is known, we return the UN flag
+        }
+    }
+   //qDebug()  << "DataProxy_SQLite::getISOName: NO ISO Name: default"  << endl;
+    return "un"; // When no flag is known, we return the UN flag
+}
