@@ -48,9 +48,13 @@
 #include "dxcluster.h"
 #include "awards.h"
 #include "mainwindowsattab.h"
+#include "mainwindowmydatatab.h"
+#include "mainwindowinputcomment.h"
+#include "mainwindowinputothers.h"
 #include "elogclublog.h"
 #include "utilities.h"
 #include "downloadcty.h"
+#include "dxccstatuswidget.h"
 
 class QTimer;
 class QDateTime;
@@ -129,7 +133,7 @@ private slots:
 
     void slotModeComboBoxChanged();
     void slotBandComboBoxChanged();
-    void slotIOTAComboBoxChanged();
+    //void slotIOTAComboBoxChanged();
     void slotOperatingYearComboBoxChanged();
     void slotOKButtonClicked();
     void slotSpotItButtonClicked();
@@ -170,6 +174,8 @@ private slots:
     void slotQSLSentComboBoxChanged();
     void sloteQSLRecvComboBoxChanged();
     void sloteQSLSentComboBoxChanged();
+    void slotLotwRecvComboBoxChanged();
+    void slotLotwSentComboBoxChanged();
     void slotQSLViaTextChanged();
 
     void slotSetPropMode(const QString _p);
@@ -295,8 +301,8 @@ private:
     QString readDataFromUIDX();
     QString readDataFromUIDXModifying();
 
-    int getDXCCFromComboBox();
-    QString getPropModeFromComboBox();
+    //int getDXCCFromComboBox();
+    //QString getPropModeFromComboBox();
 
     //QString readDataFromUICQWW();
 
@@ -332,7 +338,7 @@ private:
     void updateQSLRecAndSent();
     double checkFreqRanges(double _f);
 
-    void selectCorrectComboBoxEntity(const int _ent); // Select the appropriate entity in the ComboBox
+    //void selectCorrectComboBoxEntity(const int _ent); // Select the appropriate entity in the ComboBox
 
     //int Km2Mile(const bool _imperialSystemSelected, const bool _dataInMiles, const int _km);
 
@@ -364,7 +370,7 @@ private:
     //QLabel distShortLabelN;
     //QLabel distLongLabelN;
 
-
+    DXCCStatusWidget *dxccStatusWidget;
     QSqlRelationalTableModel *logModel;
     QWidget *logPanel;
     QTableView *logView;
@@ -458,8 +464,9 @@ private:
     QStringList entitiesList, propModeList;
 
     // UI DX
-    QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
+    //QLabel *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel; //entityPrimLabel
     QLabel *infoLabel1, *infoLabel2;
+    //QPushButton *flagIcon; // To paint a flag of the worked entity
     QLabel *bandLabel1, *bandLabel2, *bandLabel3, *bandLabel4;
     QLabel *bandLabel5, *bandLabel6, *bandLabel7, *bandLabel8;
     QLabel *bandLabel9, *bandLabel10, *bandLabel11, *bandLabel12;
@@ -467,11 +474,11 @@ private:
     QLabel *gradShortLabel, *distShortLabel;
     QLabel *gradLongLabel, *distLongLabel;
 
-    QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
+    //QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
     QComboBox *operatingYearsComboBox;
-    QLineEdit *iotaNumberLineEdit, *operatorLineEdit, *stationCallSignLineEdit, *myLocatorLineEdit, *commentLineEdit;
+    QLineEdit *operatorLineEdit, *stationCallSignLineEdit, *myLocatorLineEdit;//, *commentLineEdit, *iotaNumberLineEdit;
     QTextEdit *notesTextEdit;
-    QDoubleSpinBox *myPowerSpinBox, *rxPowerSpinBox,  *txFreqSpinBox, *rxFreqSpinBox;
+    QDoubleSpinBox *rxPowerSpinBox,  *txFreqSpinBox, *rxFreqSpinBox; //*myPowerSpinBox,
     QLCDNumber *freqQLCDNumber;
     QLCDNumber *dxccConfirmedQLCDNumber, *dxccWorkedQLCDNumber,
                 *wazConfirmedQLCDNumber, *wazWorkedQLCDNumber,
@@ -495,6 +502,9 @@ private:
     bool qslingNeeded;
 
     MainWindowSatTab *satTabWidget;
+    MainWindowMyDataTab *myDataTabWidget;
+    MainWindowInputComment *commentTabWidget;
+    MainWindowInputOthers *othersTabWidget;
     bool keepSatPage;
 
     // UI DX
