@@ -95,7 +95,9 @@ SetupDialog::SetupDialog(const bool _firstTime)
     QPushButton *okButton = new QPushButton(tr("OK"));
 
     connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
-    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
+    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));       
+    connect (logsPage, SIGNAL(newLogData(QStringList)), this, SLOT(slotAnalyzeNewLogData(QStringList)));
+
 
     QHBoxLayout *horizontalLayout = new QHBoxLayout;
     horizontalLayout->addWidget(tabWidget);
@@ -120,14 +122,14 @@ SetupDialog::SetupDialog(const bool _firstTime)
         tabWidget->setCurrentIndex(logsPageTabN);
     }
     nolog = !(haveAtleastOneLog());
-   //qDebug() << "SetupDialog::SetupDialog END" << endl;
+  //qDebug() << "SetupDialog::SetupDialog 1 END" << endl;
 }
 
 
 
 SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-    //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+   //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     util = new Utilities;
     firstTime = _firstTime;
     dataProxy = new DataProxy_SQLite();
@@ -187,6 +189,7 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
         tabWidget->setCurrentIndex(logsPageTabN);
     }
     nolog = !(haveAtleastOneLog());
+    //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
 }
 
 SetupDialog::~SetupDialog()
@@ -336,13 +339,18 @@ void SetupDialog::slotOkButtonClicked()
 
     if (!haveAtleastOneLog())
     {
-        //qDebug() << "SetupDialog::slotOkButonClicked - NO LOG!" << endl;
+       //qDebug() << "SetupDialog::slotOkButonClicked - NO LOG!" << endl;
 
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
         msgBox.setText(tr("You have not selected the kind of log you want.\nYou will be redirected to the Log tab.\nPlease add and select the kind of log you want to use."));
         msgBox.exec();
-        tabWidget->setCurrentIndex(logsPageTabN);
+
+        tabWidget->setCurrentIndex(tabWidget->indexOf(logsPage));
+        logsPage->createNewLog();
+        //emit newLogRequested(true); // Signal to be catched by logsPage true show new log
+
+
         return;
     }
 
@@ -625,6 +633,7 @@ bool SetupDialog::processConfigLine(const QString _line)
         miscPage->setDefaultFileName(value);
     }else if (tab=="DEFAULTADIFFILE"){
         miscPage->setDefaultFileName(value.toLower());
+        //qDebug() << "SetupDialog::processConfigLine: FILE: " << value << endl;
     }else if (tab=="IMPERIALSYSTEM"){
         miscPage->setImperial(value.toLower());
     }else if (tab=="KEEPMYDATA"){
@@ -984,3 +993,17 @@ void SetupDialog::checkIfNewBandOrMode()
     //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << endl;
 
 }
+
+
+void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
+{
+   //qDebug() << "SetupDialog::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
+    //qDebug() << "SetupDialog::slotAnalyzeNewLogData" << endl;
+ // We receive the station callsign and operators from the logs tab
+    if (_qs.length()!=2)
+    {
+        return;
+    }
+    userDataPage->setStationQrz(_qs.at(0));
+    userDataPage->setOperators(_qs.at(1));
+}
