@@ -55,7 +55,7 @@ class SetupDialog : public QDialog
 
 public:
     SetupDialog(const bool _firstTime=true);
-    SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page=0, const bool _firstTime = true);
+    SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page=0, const bool _firstTime = true);    
     ~SetupDialog();
 
     void setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime=true);
@@ -66,12 +66,14 @@ public slots:
 
 signals:
     void exitSignal(const int status); // 1 = OK, -1 = NOK, 2 = Cancel clicked
+    //void newLogRequested(const bool _s); // true show new log
 
 private slots:
     void changePage(QListWidgetItem *current, QListWidgetItem *previous);
     void slotReadConfigData();
     void slotOkButtonClicked();
     void slotCancelButtonClicked();
+    void slotAnalyzeNewLogData(const QStringList _qs); // We receive the station callsign and operators from the logs tab
 
 private:
 
