@@ -44,6 +44,10 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
     contestBands = -1;
     typeContestN = -1;
 
+    selectedLog = -1;
+
+    //setupD = new SetupDialog();
+
     currentLogs = new QComboBox();
     logsAvailable.clear();
 
@@ -92,6 +96,8 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
     dataProxy = new DataProxy_SQLite();
 
     //connect(newLogPushButton, SIGNAL(clicked ( )), this, SLOT(slotNewButtonClicked() ) );
+    //QObject::connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
+    //connect(setupD, SIGNAL(newLogRequested(true)), this, slotNewButtonClicked() )
 
 
     createActions();
@@ -106,12 +112,20 @@ SetupPageLogs::~SetupPageLogs(){
 }
 
 
+void SetupPageLogs::createNewLog()
+{
+   //qDebug() << "SetupPageLogs::createNewLog" << endl;
+    selectedLog = -1;
+    //newLog->clear();
+    newLog->setEditing(false);
+    newLog->exec();
+}
 
 void SetupPageLogs::slotNewButtonClicked()
 {
     //qDebug() << "SetupPageLogs::slotNewButtonClicked" << endl;
 
-    newLog->exec();
+    createNewLog();
 }
 
 void SetupPageLogs::slotEditButtonClicked()
@@ -120,7 +134,7 @@ void SetupPageLogs::slotEditButtonClicked()
     QSqlQuery query;
     int nameCol = -1;
 
-    int selectedLog = getSelectedLog();
+    selectedLog = getSelectedLog();
     //qDebug() << "SetupPageLogs::slotEditButtonClicked-1 (selectedlog: " << QString::number(selectedLog) << ")" << endl;
     QString stringQuery = QString("SELECT * FROM logs WHERE id='%1'").arg(selectedLog);
     //qDebug() << "SetupPageLogs::slotEditButtonClicked -2" << endl;
@@ -140,6 +154,9 @@ void SetupPageLogs::slotEditButtonClicked()
             nameCol = rec.indexOf("stationcall");
             newLog->setStationCallSign((query.value(nameCol)).toString());
 
+            nameCol = rec.indexOf("operators");
+            newLog->setOperators((query.value(nameCol)).toString());
+
             nameCol = rec.indexOf("comment");
             newLog->setComment((query.value(nameCol)).toString());
 
@@ -156,6 +173,11 @@ void SetupPageLogs::slotEditButtonClicked()
     }
 }
 
+void SetupPageLogs::slotLogsCancelled(const bool _q)
+{
+    selectedLog = -1;
+}
+
 void SetupPageLogs::slotRemoveButtonClicked()
 {
     //qDebug() << "SetupPageLogs::slotRemoveButtonClicked" << endl;
@@ -332,7 +354,7 @@ QStringList SetupPageLogs::readLogs()
     QSqlQuery query;
     int nameCol = -1;
     bool sqlOk = false;
-    QDate date = QDate::currentDate();
+    //QDate date = QDate::currentDate();
     aux2.clear();
     aux.clear();
     _logs.clear();
@@ -387,7 +409,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
 {
     //qDebug() << "SetupPageLogs::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
 
-    if (_qs.length()!=13)
+    if (_qs.length()!=14)
     {
         return;
     }
@@ -403,6 +425,7 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
             << QString::number(contestBands)
             << QString::number(contestCatOverlay)
             << QString::number(typeContest);
+            << editing (1/0)
 
 
 */
@@ -418,18 +441,33 @@ void SetupPageLogs::slotAnalyzeNewLogData(const QStringList _qs)
     contestCatBands  = (_qs.at(9)).toInt();
     contestBands  = (_qs.at(10)).toInt();
     typeContestN = (_qs.at(12)).toInt();
+    bool editing;
+    if ( (_qs.at(13)).toInt() == 1)
+    {
+        editing = true;
+    }
+    else
+    {
+        editing = false;
+    }
     //OVERLAY = 11
 
 
     QStringList newLogq;
     newLogq.clear();
-    newLogq << dateString << stationCallsign << _qs.at(4) << comment << _qs.at(12);
+    //If qs.at(12) == 1 then we are editing, any other value is a new log
+    newLogq << dateString << stationCallsign << operators << _qs.at(4) << comment << _qs.at(12) << QString::number(selectedLog) << _qs.at(13) ;
     if (dataProxy->addNewLog(newLogq))
     {
         logsModel->select();
         updateSelectedLogs();
     }
 
+    // We send the data to the main tab
+    QStringList logData;
+    logData.clear();
+    logData << stationCallsign << operators;
+    emit newLogData(logData);
 }
 /*
 bool SetupPageLogs::addNewLog(const QStringList _qs)
