@@ -31,10 +31,9 @@
 #include <QtSql>
 #include "dataproxy.h"
 #include "dataproxy_sqlite.h"
-
-
 #include "setuppagelogsnew.h"
 
+
 const int CONTEST_DX = 0;
 const int CONTEST_CQ_WW_SSB = 1;
 const int CONTEST_CQ_WW_CW = 2;
@@ -49,6 +48,7 @@ public:
     ~SetupPageLogs();
     int getSelectedLog();
     void setSelectedLog(const int _i);
+    void createNewLog();
 /*
     QString getBands(); // 10m, 12m, 15m
     QString getModes(); //ssb, CW
@@ -72,12 +72,14 @@ private slots:
     void slotAnalyzeNewLogData(const QStringList _qs);
     void slotLogSelected(const QModelIndex & index);
     void slotLogDoubleClicked(const QModelIndex & index);
+    void slotLogsCancelled(const bool _q);
 
     //void slotCreateLog();
 
         //
 signals:
    //void exitSignal(const int status); // 1 = OK, -1 = NOK, 2 = Cancel clicked
+    void newLogData(const QStringList _qs); // Station QRZ + Operators to be shown in the main tab
 
 private:
     //void createActions();
@@ -124,6 +126,9 @@ private:
     int contestCatMode, contestCatOperators, contestCatAssisted, contestCatPower, contestCatBands, contestBands, typeContestN;
 
     DataProxy *dataProxy;
+    int selectedLog;
+
+
 };
 
 
