@@ -102,6 +102,26 @@ SetupPageLogsNew::SetupPageLogsNew(QWidget *parent)
 
 }
 
+void SetupPageLogsNew::clear()
+{
+    stationCallsignLineEdit->clear();
+    operatorsLineEdit->clear();
+    dateEdit->setDate(QDate::currentDate ());
+
+
+    typeComboBox->setCurrentIndex(0);
+    contestCatModeComboBox->setCurrentIndex(0);
+    contestCatOperatorsComboBox->setCurrentIndex(0);
+    contestCatAssistedComboBox->setCurrentIndex(0);
+    contestCatPowerComboBox->setCurrentIndex(0);
+    contestCatBandsComboBox->setCurrentIndex(0);
+    contestBandsComboBox->setCurrentIndex(0);
+    contestCatOverlayComboBox->setCurrentIndex(0);
+    contestCatModeComboBox->setCurrentIndex(0);
+
+
+}
+
 void SetupPageLogsNew::createWidget()
 {
     //qDebug() << "SetupPageLogsNew::createWidget" << endl;
@@ -546,8 +566,8 @@ void SetupPageLogsNew::slotOKButtonClicked()
         return;
     }
 
-
     operators = operatorsLineEdit->text();
+    //TODO: Check if operators is really including a comma separated list of QRZ
     comment = commentLineEdit->text();    
     dateString = dateEdit->date().toString("yyyy/MM/dd");
 
@@ -565,7 +585,6 @@ void SetupPageLogsNew::slotOKButtonClicked()
         //qDebug() << "SetupPageLogsNew::slotOkButtonClicked NOT ENA: type" << endl;
         typeContestSelected = 0;
         typeConteststr = QString();
-
     }
 
     if (contestCatModeComboBox->isEnabled())
@@ -681,6 +700,16 @@ void SetupPageLogsNew::gatherAndSend()
             << QString::number(contestBands)
             << QString::number(contestCatOverlay)
             << QString::number(typeContest);
+
+    if (editing)
+    {
+        logData << "1";
+        editing = false;
+    }
+    else
+    {
+        logData << "0";
+    }
     //logData << QString::number(typeContest)
     // Update the SetupPageLogs::slotAnalyzeNewLogData if you add or remove any field (Today 12)
     emit newLogData(logData);
@@ -691,6 +720,7 @@ void SetupPageLogsNew::slotCancelButtonClicked()
 {
     //qDebug() << "SetupPageLogsNew::slotCancelButtonClicked" << endl;
     logData.clear();
+    emit cancelled(true);
     close();
 }
 
@@ -708,7 +738,7 @@ QStringList SetupPageLogsNew::getValidCatOptions(const int _currentCat, const in
 
     //qDebug() << "SetupPageLogsNew::getValidCatOptions: " << QString::number(_currentCat) <<"/"<< QString::number(_higherCat) << endl;
     //return dataProxy->getValidCatOptions(_currentCat, _higherCat);
-
+    return QStringList();
 }
 
 bool SetupPageLogsNew::isThereAnyNotManagedLog()
@@ -735,6 +765,7 @@ bool SetupPageLogsNew::isThereAnyNotManagedLog()
         //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog tras el while" << endl;
     }
     //qDebug() << "SetupPageLogsNew::isThereAnyNotManagedLog END" << endl;
+    return false;
 }
 
 void SetupPageLogsNew::setStationCallSign(const QString _st)
@@ -817,6 +848,11 @@ void SetupPageLogsNew::setCOverlay(const int _n)
 void SetupPageLogsNew::setEditing(const bool b)
 {
     editing = b;
+    if (!editing)
+    {
+        clear();
+    }
+
 }
 
 int SetupPageLogsNew::getSelectedTypeContest()
