@@ -62,6 +62,7 @@ public:
     void setCOverlay(const int _n);
 
 
+
 private slots:
     void slotOKButtonClicked();
     void slotCancelButtonClicked();
@@ -80,6 +81,7 @@ private slots:
 
 signals:
     void newLogData(const QStringList _qs); //
+    void cancelled(const bool _c); // Cancel button is clicked
 
 private:
 
@@ -92,6 +94,7 @@ private:
     void updateAllCats();
     void showOK();
     void showNOK();
+    void clear();
 
 
     DataProxy *dataProxy;
