@@ -32,6 +32,7 @@
 
 */
 #include <QString>
+#include <QtDebug>
 
 class Utilities
 {
@@ -41,6 +42,10 @@ public:
     bool trueOrFalse(const QString _s); // reads a String and return true if s.upper()== TRUE :-)
     QString checkAndFixASCIIinADIF(const QString _data);
 
+    //Devel or debug functions - Not adding any feature to the user
+    void printQString(const QStringList _qs);
+
+
 
 };
 
