@@ -106,11 +106,13 @@ public:
     bool checkQRZValidFormat(const QString _qrz);
 
     QStringList getEntitiesNames();
+    int getHowManyEntities();
 
 private slots:
 
 
 private:
+    //void identifyOS();
     int getPrefixId(const QString _qrz);
     bool readCTYDAT();
     bool readCTYCSV();
@@ -135,7 +137,7 @@ private:
     double lat, lon, utc;
     //QString line;
     //bool readingDataOfAnEntity;
-    int nullValue;
+    int nullValue;    
 
     QSqlRelationalTableModel *worldModel;
     //QProgressBar *progressBar;
@@ -143,6 +145,9 @@ private:
     Locator *locator;
     DataProxy *dataProxy;
     //Awards *awards;
+    //FLAGS
+    //QString flagsDir;
+    //FLAGS-END
 
 };
 
